@@ -6,4 +6,5 @@ mod retry_policy;
 pub use exponential_retry::*;
 pub use fixed_retry::*;
 pub use no_retry::*;
-use retry_policy::RetryPolicy;
+pub(crate) use retry_policy::get_retry_after;
+pub use retry_policy::RetryPolicy;
