@@ -11,11 +11,11 @@ impl ContentLength {
 
 impl Header for ContentLength {
     fn name(&self) -> headers::HeaderName {
-        http::header::CONTENT_LENGTH.into()
+        headers::CONTENT_LENGTH
     }
 
     fn value(&self) -> headers::HeaderValue {
         let count = if self.0 < 0 { -1 } else { self.0 };
-        format!("{}", count).into()
+        format!("{count}").into()
     }
 }
