@@ -1,6 +1,6 @@
 use crate::headers::{self, Header};
 
-#[derive(Debug, Clone, PartialEq)]
+#[derive(Debug, Clone, PartialEq, Eq)]
 pub enum IfSourceMatchCondition {
     Match(String),
     NotMatch(String),
@@ -12,14 +12,13 @@ impl Header for IfSourceMatchCondition {
             IfSourceMatchCondition::Match(_) => headers::SOURCE_IF_MATCH,
             IfSourceMatchCondition::NotMatch(_) => headers::SOURCE_IF_NONE_MATCH,
         }
-        .into()
     }
 
     fn value(&self) -> headers::HeaderValue {
         match self.clone() {
-            IfSourceMatchCondition::Match(etag) => etag,
-            IfSourceMatchCondition::NotMatch(etag) => etag,
+            IfSourceMatchCondition::Match(etag) | IfSourceMatchCondition::NotMatch(etag) => {
+                etag.into()
+            }
         }
-        .into()
     }
 }
