@@ -1,26 +1,27 @@
-use crate::headers::{self, Header};
-use chrono::{DateTime, Utc};
+use crate::{
+    date,
+    headers::{self, Header, HeaderName},
+};
+use time::OffsetDateTime;
 
-#[derive(Debug, Clone, Copy, PartialEq)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq)]
 pub enum IfSourceModifiedSinceCondition {
-    Modified(DateTime<Utc>),
-    Unmodified(DateTime<Utc>),
+    Modified(OffsetDateTime),
+    Unmodified(OffsetDateTime),
 }
 
 impl Header for IfSourceModifiedSinceCondition {
-    fn name(&self) -> headers::HeaderName {
+    fn name(&self) -> HeaderName {
         match self {
             IfSourceModifiedSinceCondition::Modified(_) => headers::SOURCE_IF_MODIFIED_SINCE,
             IfSourceModifiedSinceCondition::Unmodified(_) => headers::SOURCE_IF_UNMODIFIED_SINCE,
         }
-        .into()
     }
 
     fn value(&self) -> headers::HeaderValue {
         match self {
-            IfSourceModifiedSinceCondition::Modified(date) => date.to_rfc2822(),
-            IfSourceModifiedSinceCondition::Unmodified(date) => date.to_rfc2822(),
+            IfSourceModifiedSinceCondition::Modified(date)
+            | IfSourceModifiedSinceCondition::Unmodified(date) => date::to_rfc1123(date).into(),
         }
-        .into()
     }
 }
