@@ -9,14 +9,14 @@ pub enum LeaseDuration {
 
 impl Header for LeaseDuration {
     fn name(&self) -> headers::HeaderName {
-        headers::LEASE_DURATION.into()
+        headers::LEASE_DURATION
     }
 
     fn value(&self) -> headers::HeaderValue {
         match self {
             LeaseDuration::Infinite => "-1".to_owned(),
             LeaseDuration::Seconds(seconds) => {
-                format!("{}", seconds)
+                format!("{seconds}")
             }
         }
         .into()
