@@ -13,11 +13,23 @@ impl MaxItemCount {
 
 impl Header for MaxItemCount {
     fn name(&self) -> headers::HeaderName {
-        headers::MAX_ITEM_COUNT.into()
+        headers::MAX_ITEM_COUNT
     }
 
     fn value(&self) -> headers::HeaderValue {
         let count = if self.0 <= 0 { -1 } else { self.0 };
-        format!("{}", count).into()
+        format!("{count}").into()
+    }
+}
+
+impl From<i32> for MaxItemCount {
+    fn from(count: i32) -> Self {
+        Self::new(count)
+    }
+}
+
+impl Default for MaxItemCount {
+    fn default() -> Self {
+        MaxItemCount::new(-1)
     }
 }
