@@ -1,5 +1,4 @@
-use crate::AppendToUrlQuery;
-use std::convert::TryFrom;
+use crate::{AppendToUrlQuery, Url};
 use std::num::NonZeroU32;
 
 // This type forbids zero as value.
@@ -17,7 +16,7 @@ impl MaxResults {
 }
 
 impl AppendToUrlQuery for MaxResults {
-    fn append_to_url_query(&self, url: &mut url::Url) {
+    fn append_to_url_query(&self, url: &mut Url) {
         url.query_pairs_mut()
             .append_pair("maxresults", &format!("{}", self.0));
     }
@@ -36,8 +35,7 @@ impl TryFrom<u32> for MaxResults {
         match NonZeroU32::new(max_results) {
             Some(max_results) => Ok(max_results.into()),
             None => Err(format!(
-                "number {} is not a valid NonZeroU32 value",
-                max_results
+                "number {max_results} is not a valid NonZeroU32 value"
             )),
         }
     }
