@@ -1,9 +1,10 @@
-use super::Continuation;
-use crate::{AppendToUrlQuery, Error, HttpHeaderError};
-
+use crate::{
+    headers::{self, Headers},
+    AppendToUrlQuery, Url,
+};
 use serde::{Deserialize, Serialize};
 
-#[derive(Debug, Clone, PartialEq, Serialize, Deserialize)]
+#[derive(Debug, Clone, PartialEq, Eq, Serialize, Deserialize)]
 pub struct NextMarker(String);
 
 impl NextMarker {
@@ -12,14 +13,10 @@ impl NextMarker {
     }
 
     pub fn from_possibly_empty_string(next_marker: Option<String>) -> Option<Self> {
-        if let Some(nm) = next_marker {
-            if nm.is_empty() {
-                None
-            } else {
-                Some(NextMarker::new(nm))
-            }
-        } else {
+        if let Some("") = next_marker.as_deref() {
             None
+        } else {
+            next_marker.map(Into::into)
         }
     }
 
@@ -27,16 +24,12 @@ impl NextMarker {
         &self.0
     }
 
-    pub fn append_to_url_query_as_continuation(&self, url: &mut url::Url) {
+    pub fn append_to_url_query_as_continuation(&self, url: &mut Url) {
         url.query_pairs_mut().append_pair("continuation", &self.0);
     }
 
-    pub fn from_header_optional(headers: &http::HeaderMap) -> Result<Option<Self>, Error> {
-        let header_as_str = headers
-            .get("x-ms-continuation")
-            .map(|item| item.to_str())
-            .transpose()
-            .map_err(HttpHeaderError::ToStr)?;
+    pub fn from_header_optional(headers: &Headers) -> crate::Result<Option<Self>> {
+        let header_as_str = headers.get_optional_str(&headers::CONTINUATION);
 
         Ok(header_as_str
             .filter(|h| !h.is_empty())
@@ -45,17 +38,11 @@ impl NextMarker {
 }
 
 impl AppendToUrlQuery for NextMarker {
-    fn append_to_url_query(&self, url: &mut url::Url) {
+    fn append_to_url_query(&self, url: &mut Url) {
         url.query_pairs_mut().append_pair("marker", &self.0);
     }
 }
 
-impl From<Continuation> for NextMarker {
-    fn from(next_marker: Continuation) -> Self {
-        Self::new(next_marker.into_raw())
-    }
-}
-
 impl From<String> for NextMarker {
     fn from(next_marker: String) -> Self {
         Self::new(next_marker)
