@@ -2,7 +2,7 @@ use crate::headers::{self, Header};
 use std::str::FromStr;
 use uuid::Uuid;
 
-#[derive(Debug, Clone, Copy, PartialEq)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq)]
 pub struct SourceLeaseId(Uuid);
 
 impl std::fmt::Display for SourceLeaseId {
@@ -21,7 +21,7 @@ impl std::str::FromStr for SourceLeaseId {
 
 impl Header for SourceLeaseId {
     fn name(&self) -> headers::HeaderName {
-        headers::SOURCE_LEASE_ID.into()
+        headers::SOURCE_LEASE_ID
     }
 
     fn value(&self) -> headers::HeaderValue {
